@@ -154,79 +154,74 @@ function lol() {
 }
 function _main() {
     _main = _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
-        var _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, _value, x;
+        var _iteratorAbruptCompletion, _didIteratorError, _iteratorError, _iterator, _step, _value, x;
         return regeneratorRuntime.wrap(function _callee$(_ctx) {
             while(1)switch(_ctx.prev = _ctx.next){
                 case 0:
-                    _iteratorNormalCompletion = true, _didIteratorError = false;
+                    _iteratorAbruptCompletion = false, _didIteratorError = false;
                     _ctx.prev = 1;
                     _iterator = _asyncIterator(lol());
                 case 3:
                     _ctx.next = 5;
                     return _iterator.next();
                 case 5:
-                    _step = _ctx.sent;
-                    _iteratorNormalCompletion = _step.done;
-                    _ctx.next = 9;
-                    return _step.value;
-                case 9:
-                    _value = _ctx.sent;
-                    if (!(0, !_iteratorNormalCompletion)) {
-                        _ctx.next = 15;
+                    if (!(_iteratorAbruptCompletion = !(_step = _ctx.sent).done)) {
+                        _ctx.next = 10;
                         break;
                     }
                     {
+                        _value = _step.value;
                         x = _value;
                         console.log(x);
                     }
-                case 12:
-                    _iteratorNormalCompletion = true;
+                case 7:
+                    _iteratorAbruptCompletion = false;
                     _ctx.next = 3;
                     break;
-                case 15:
-                    _ctx.next = 21;
+                case 10:
+                    _ctx.next = 16;
                     break;
-                case 17:
-                    _ctx.prev = 17;
+                case 12:
+                    _ctx.prev = 12;
                     _ctx.t0 = _ctx["catch"](1);
                     _didIteratorError = true;
                     _iteratorError = _ctx.t0;
-                case 21:
-                    _ctx.prev = 21;
-                    _ctx.prev = 22;
-                    if (!(!_iteratorNormalCompletion && _iterator.return != null)) {
-                        _ctx.next = 26;
+                case 16:
+                    _ctx.prev = 16;
+                    _ctx.prev = 17;
+                    if (!(_iteratorAbruptCompletion && _iterator.return != null)) {
+                        _ctx.next = 21;
                         break;
                     }
-                    _ctx.next = 26;
+                    _ctx.next = 21;
                     return _iteratorError.return();
-                case 26:
-                    _ctx.prev = 26;
+                case 21:
+                    _ctx.prev = 21;
                     if (!_didIteratorError) {
-                        _ctx.next = 29;
+                        _ctx.next = 24;
                         break;
                     }
                     throw _iteratorError;
-                case 29:
-                    return _ctx.finish(26);
-                case 30:
+                case 24:
                     return _ctx.finish(21);
-                case 31:
+                case 25:
+                    return _ctx.finish(16);
+                case 26:
                 case "end":
                     return _ctx.stop();
             }
         }, _callee, null, [
             [
-                22,
+                17,
                 ,
-                26,
-                30
+                21,
+                25
             ],
             [
                 1,
-                17,
-                21,
-                31
+                12,
+                16,
+                26
             ]
         ]);
     }));
